@@ -44,6 +44,12 @@ const (
 	ArgAppLogType = "type"
 	// ArgAppDeployment is the deployment ID.
 	ArgAppDeployment = "deployment"
+	// ArgAppJobName is the job name.
+	ArgAppJobName = "job-name"
+	// ArgAppJobInvocation is the job invocation ID.
+	ArgAppJobInvocation = "job-invocation"
+	// ArgAppInstanceName is the instance name of currently running instances (optional).
+	ArgAppInstanceName = "instance-name"
 	// ArgAppDevConfig is the path to the app dev link config.
 	ArgAppDevConfig = "dev-config"
 	// ArgBuildCommand is an optional build command to set for local development.
@@ -116,6 +122,23 @@ const (
 	// ArgAutoscaleTargetInstances is an autoscale target instance argument.
 	ArgAutoscaleTargetInstances = "target-instances"
 
+	// ArgVPCNATGatewayName is a vpc nat gateway name argument.
+	ArgVPCNATGatewayName = "name"
+	// ArgVPCNATGatewayType is a vpc nat gateway type argument.
+	ArgVPCNATGatewayType = "type"
+	// ArgVPCNATGatewayRegion is a vpc nat gateway region argument.
+	ArgVPCNATGatewayRegion = "region"
+	// ArgVPCNATGatewaySize is a vpc nat gateway region argument.
+	ArgVPCNATGatewaySize = "size"
+	// ArgVPCNATGatewayVPCs is a vpc nat gateway vpcs argument.
+	ArgVPCNATGatewayVPCs = "vpcs"
+	// ArgVPCNATGatewayUDPTimeout is a vpc nat gateway udp-timeout argument.
+	ArgVPCNATGatewayUDPTimeout = "udp-timeout"
+	// ArgVPCNATGatewayICMPTimeout is a vpc nat gateway icmp-timeout argument.
+	ArgVPCNATGatewayICMPTimeout = "icmp-timeout"
+	// ArgVPCNATGatewayTCPTimeout is a vpc nat gateway tcp-timeout argument.
+	ArgVPCNATGatewayTCPTimeout = "tcp-timeout"
+
 	// ArgHA is a cluster's highly available control plane argument.
 	ArgHA = "ha"
 	// ArgEnableControlPlaneFirewall enable control plane firewall.
@@ -126,8 +149,14 @@ const (
 	ArgClusterAutoscalerScaleDownUtilizationThreshold = "scale-down-utilization-threshold"
 	// ArgClusterAutoscalerScaleDownUnneededTime is the cluster autoscaler scale down unneeded time
 	ArgClusterAutoscalerScaleDownUnneededTime = "scale-down-unneeded-time"
+	// ArgClusterAutoscalerExpanders customizes the expanders used by the cluster autoscaler to scale up the cluster.
+	ArgClusterAutoscalerExpanders = "expanders"
 	// ArgEnableRoutingAgent enables the routing-agent cluster plugin.
 	ArgEnableRoutingAgent = "enable-routing-agent"
+	// ArgEnableAmdGpuDevicePlugin enables automatic amd gpu device plugin installation.
+	ArgEnableAmdGpuDevicePlugin = "enable-amd-gpu-device-plugin"
+	// ArgEnableAmdGpuDeviceMetricsExporterPlugin enables automatic amd gpu device metrics exporter plugin installation.
+	ArgEnableAmdGpuDeviceMetricsExporterPlugin = "enable-amd-gpu-device-metrics-exporter-plugin"
 	// ArgSurgeUpgrade is a cluster's surge-upgrade argument.
 	ArgSurgeUpgrade = "surge-upgrade"
 	// ArgCommandUpsert is an upsert for a resource to be created or updated argument.
@@ -393,6 +422,8 @@ const (
 	ArgLoadBalancerNetwork = "network"
 	// ArgLoadBalancerNetworkStack is the network stack type the load balancer will be configured with (e.g IPv4, Dual Stack: IPv4 and IPv6).
 	ArgLoadBalancerNetworkStack = "network-stack"
+	// ArgLoadBalancerTLSCipherPolicy is the tls cipher policy to be used for the load balancer
+	ArgLoadBalancerTLSCipherPolicy = "tls-cipher-policy"
 
 	// ArgFirewallName is a name of the firewall.
 	ArgFirewallName = "name"
@@ -525,28 +556,32 @@ const (
 	// ArgVPCPeeringVPCID is id of the VPC.
 	ArgVPCPeeringVPCID = "vpc-id"
 
-	// ArgInterconnectAttachmentType is the type of the Interconnect Attachment e.g. "partner".
-	ArgInterconnectAttachmentType = "type"
-	// ArgPartnerInterconnectAttachmentName is a name of the Partner Interconnect Attachment.
-	ArgPartnerInterconnectAttachmentName = "name"
-	// ArgPartnerInterconnectAttachmentConnectionBandwidthInMbps is the connection bandwidth in megabits per second.
-	ArgPartnerInterconnectAttachmentConnectionBandwidthInMbps = "connection-bandwidth-in-mbps"
-	// ArgPartnerInterconnectAttachmentRegion is the region slug.
-	ArgPartnerInterconnectAttachmentRegion = "region"
-	// ArgPartnerInterconnectAttachmentNaaSProvider is the name of the Network as a Service provider
-	ArgPartnerInterconnectAttachmentNaaSProvider = "naas-provider"
-	// ArgPartnerInterconnectAttachmentVPCIDs are the IDs of the VPCs which the Partner Interconnect Attachment is connected
-	ArgPartnerInterconnectAttachmentVPCIDs = "vpc-ids"
-	// ArgPartnerInterconnectAttachmentBGPLocalASN is the BGP Autonomous System Number (ASN) of the local device
-	ArgPartnerInterconnectAttachmentBGPLocalASN = "bgp-local-asn"
-	// ArgPartnerInterconnectAttachmentBGPLocalRouterIP is the BGP IP address of the local device
-	ArgPartnerInterconnectAttachmentBGPLocalRouterIP = "bgp-local-router-ip"
-	// ArgPartnerInterconnectAttachmentBGPPeerASN is the BGP Autonomous System Number (ASN) of the peer device
-	ArgPartnerInterconnectAttachmentBGPPeerASN = "bgp-peer-asn"
-	// ArgPartnerInterconnectAttachmentBGPPeerIPAddress is the BGP IP address of the peer device
-	ArgPartnerInterconnectAttachmentBGPPeerRouterIP = "bgp-peer-router-ip"
-	// ArgPartnerInterconnectAttachmentBGPAuthKey is the BGP MD5 authentication key
-	ArgPartnerInterconnectAttachmentBGPAuthKey = "bgp-auth-key"
+	// ArgPartnerAttachmentType is the type of the Partner Attachment e.g. "partner".
+	ArgPartnerAttachmentType = "type"
+	// ArgPartnerAttachmentName is a name of the Partner Attachment.
+	ArgPartnerAttachmentName = "name"
+	// ArgPartnerAttachmentBandwidthInMbps is the connection bandwidth in megabits per second.
+	ArgPartnerAttachmentBandwidthInMbps = "connection-bandwidth-in-mbps"
+	// ArgPartnerAttachmentRegion is the region slug.
+	ArgPartnerAttachmentRegion = "region"
+	// ArgPartnerAttachmentNaaSProvider is the name of the Network as a Service provider
+	ArgPartnerAttachmentNaaSProvider = "naas-provider"
+	// ArgPartnerAttachmentVPCIDs are the IDs of the VPCs which the Partner Attachment is connected
+	ArgPartnerAttachmentVPCIDs = "vpc-ids"
+	// ArgPartnerAttachmentBGPLocalASN is the BGP Autonomous System Number (ASN) of the local device
+	ArgPartnerAttachmentBGPLocalASN = "bgp-local-asn"
+	// ArgPartnerAttachmentBGPLocalRouterIP is the BGP IP address of the local device
+	ArgPartnerAttachmentBGPLocalRouterIP = "bgp-local-router-ip"
+	// ArgPartnerAttachmentBGPPeerASN is the BGP Autonomous System Number (ASN) of the peer device
+	ArgPartnerAttachmentBGPPeerASN = "bgp-peer-asn"
+	// ArgPartnerAttachmentBGPPeerRouterIP is the BGP IP address of the peer device
+	ArgPartnerAttachmentBGPPeerRouterIP = "bgp-peer-router-ip"
+	// ArgPartnerAttachmentBGPAuthKey is the BGP MD5 authentication key
+	ArgPartnerAttachmentBGPAuthKey = "bgp-auth-key"
+	// ArgPartnerAttachmentRedundancyZone is the redundancy zone of the Partner Attachment
+	ArgPartnerAttachmentRedundancyZone = "redundancy-zone"
+	// ArgPartnerAttachmentParentUUID is the ha parent uuid of the Partner Attachment
+	ArgPartnerAttachmentParentUUID = "parent-uuid"
 
 	// ArgReadWrite indicates a generated token should be read/write.
 	ArgReadWrite = "read-write"
@@ -627,4 +662,162 @@ const (
 
 	// ArgGPUs specifies to list GPU Droplets
 	ArgGPUs = "gpus"
+
+	// Agent Args
+
+	// ArgAgentId is the ID of the agent.
+	ArgAgentId = "agent-id"
+
+	// ArgAgentName is the name of the agent.
+	ArgAgentName = "name"
+
+	// ArgAgentInstruction is the instruction for the agent.
+	ArgAgentInstruction = "instruction"
+
+	// ArgAgentModelId is the model ID for the agent.
+	ArgModelId = "model-id"
+
+	// ArgAgentProjectId is the project ID for the agent.
+	ArgAgentProjectId = "project-id"
+
+	// ArgAgentRegion is the region where the agent is deployed.
+	ArgAgentRegion = "region"
+
+	// ArgAnthropicKeyId is the Anthropic key ID for the agent.
+	ArgAnthropicKeyId = "Anthropic-key-id"
+
+	// ArgAgentDescription is the description for the agent.
+	ArgAgentDescription = "description"
+
+	// ArgKnowledgeBaseId is the knowledge base ID(s) attached to the agent.
+	ArgKnowledgeBaseId = "knowledge-base-id"
+
+	// ArgOpenAIKeyId is the OpenAI API key ID for the agent.
+	ArgOpenAIKeyId = "openai-key-id"
+
+	// ArgTags are the tags applied to the agent.
+	ArgTags = "tags"
+
+	// ArgAgentForce forces agent deletion without confirmation.
+	ArgAgentForce = "force"
+
+	// ArgK specifies how many results should be considered from an attached knowledge base.
+	ArgK = "k"
+
+	// ArgMaxTokens is the maximum number of tokens to generate in the response.
+	ArgMaxTokens = "max-tokens"
+
+	// ArgRetrievalMethod is the method used to retrieve information from the knowledge base.
+	ArgRetrievalMethod = "retrieval-method"
+
+	// ArgTemperature is the temperature for the response generation.
+	ArgTemperature = "temperature"
+
+	// ArgTopProbability is the top probability for the response generation.
+	ArgTopProbability = "top-p"
+
+	// ArgKnowledgeBaseDatabaseID is the ID of the database
+	ArgKnowledgeBaseDatabaseID = "database-id"
+
+	// ArgKnowledgeBaseName is the name of the knowledge base
+	ArgKnowledgeBaseName = "name"
+
+	// ArgKnowledgeBaseRegion is the region of the knowledge base
+	ArgKnowledgeBaseRegion = "region"
+
+	// ArgKnowledgeBaseProjectID is the project ID of the knowledge base
+	ArgKnowledgeBaseProjectID = "project-id"
+
+	// ArgKnowledgeBaseEmbeddingModelUUID is the UUID of the embedding model
+	ArgKnowledgeBaseEmbeddingModelUUID = "embedding-model-uuid"
+
+	// ArgKnowledgeBaseTags is the tags of the knowledge base
+	ArgKnowledgeBaseTags = "tags"
+
+	// ArgKnowledgeBaseVPCUUID is the UUID of the VPC
+	ArgKnowledgeBaseVPCUUID = "vpc-uuid"
+
+	// ArgKnowledgeBaseDataSource is the data source of the knowledge base
+	ArgKnowledgeBaseDataSource = "data-sources"
+
+	// ArgKnowledgeBaseBaseURL is the base URL of the knowledge base
+	ArgKnowledgeBaseBaseURL = "base-url"
+
+	// ArgKnowledgeBaseCrawlingOption is the crawling option of the knowledge base
+	ArgKnowledgeBaseCrawlingOption = "crawling-option"
+
+	// ArgKnowledgeBaseEmbedMedia is the embed media option of the knowledge base
+	ArgKnowledgeBaseEmbedMedia = "embed-media"
+
+	// ArgKnowledgeBaseUUID is the UUID of the knowledge base
+	ArgKnowledgeBaseUUID = "uuid"
+
+	// ArgKnowledgeBaseDataSourceID is the ID of the data source
+	ArgKnowledgeBaseDataSourceID = "data-source-id"
+
+	// ArgKnowledgeBaseBucketName is name of data source from Spaces
+	ArgKnowledgeBaseBucketName = "bucket-name"
+
+	// ArgKnowledgeBaseItemPath is the item path of the data source
+	ArgKnowledgeBaseItemPath = "item-path"
+
+	// ArgPrefix is a byoip prefix argument.
+	ArgPrefix = "prefix"
+
+	// ArgSignature is a byoip prefix argument.
+	ArgSignature = "signature"
+
+	// ArgAdvertise is a byoip prefix argument.
+	ArgAdvertise = "advertise"
+
+	// ArgAgentParentID is the ID for the parent agent.
+	ArgParentAgentId = "parent-agent-id"
+
+	// ArgChildAgentID is the ID for the child agent.
+	ArgChildAgentId = "child-agent-id"
+
+	// ArgAgentRouteId is the UUID for the agent linkage.
+	ArgAgentRouteId = "route-id"
+
+	// ArgAgentRouteName is the name of the route.
+	ArgAgentRouteName = "route-name"
+
+	// ArgAgentRouteIfCase is the if-case condition for the route.
+	ArgAgentRouteIfCase = "if-case"
+
+	// ArgFunctionIDs is the name of the function.
+	ArgFunctionID = "function-id"
+
+	//ArgFunctionName is the name of the function.
+	ArgFunctionName = "name"
+
+	// ArgFunctionDescription is the description of the function.
+	ArgFunctionRouteDescription = "description"
+
+	// ArgFunctionRouteFaasName is the name of the function route in the DigitalOcean functions platform
+	ArgFunctionRouteFaasName = "faas-name"
+
+	// ArgFunctionRouteFaasNamespace is the namespace of the function route in the DigitalOcean functions platform
+	ArgFunctionRouteFaasNamespace = "faas-namespace"
+
+	// ArgFunctionRouteInputSchema is the input schema of the function route
+	ArgFunctionRouteInputSchema = "input-schema"
+
+	// ArgFunctionRouteOutputSchema is the output schema of the function route
+	ArgFunctionRouteOutputSchema = "output-schema"
+
+	// ArgAgentAPIKeyName is the name of API Key of the agent.
+	ArgAgentAPIKeyName = "name"
+
+	// ArgAgentUUID is the uuid of the apikey.
+	ArgAPIkeyUUID = "api-key-uuid"
+
+	// ArgAPIKeyForce forces API Key deletion without confirmation.
+	ArgAPIKeyForce = "force"
+
+	// ArgOpenAIKeyName is the name of the OpenAI API Key
+	ArgOpenAIKeyName = "name"
+
+	// ArgOpenAIKeyAPIKey is the API key for the OpenAI API Key
+	ArgOpenAIKeyAPIKey = "api-key"
 )
