@@ -24,6 +24,7 @@ func TestAppsCommand(t *testing.T) {
 	require.NotNil(t, cmd)
 	assertCommandNames(t, cmd,
 		"console",
+		"list-instances",
 		"create",
 		"get",
 		"list",
@@ -32,7 +33,9 @@ func TestAppsCommand(t *testing.T) {
 		"dev",
 		"create-deployment",
 		"get-deployment",
+		"get-job-invocation",
 		"list-deployments",
+		"list-job-invocations",
 		"list-regions",
 		"logs",
 		"propose",
@@ -651,10 +654,14 @@ func TestRunAppsGetLogsWithAppNameAndDeploymentID(t *testing.T) {
 func TestRunAppsConsole(t *testing.T) {
 	appID := uuid.New().String()
 	deploymentID := uuid.New().String()
-	component := "service"
+	componentName := "service"
+	instanceName := "app-instance-1d34fg678-45f6"
 
 	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
-		tm.apps.EXPECT().GetExec(appID, deploymentID, component).Times(1).Return(&godo.AppExec{URL: "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33"}, nil)
+		opts := &godo.AppGetExecOptions{
+			DeploymentID: deploymentID,
+		}
+		tm.apps.EXPECT().GetExecWithOpts(appID, componentName, opts).Times(1).Return(&godo.AppExec{URL: "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33"}, nil)
 		tm.listen.EXPECT().Listen(gomock.Any()).Times(1).Return(nil)
 		tm.terminal.EXPECT().ReadRawStdin(gomock.Any(), gomock.Any()).Times(1).Return(func() {}, nil)
 		tm.terminal.EXPECT().MonitorResizeEvents(gomock.Any(), gomock.Any()).Times(1).Return(nil)
@@ -669,7 +676,34 @@ func TestRunAppsConsole(t *testing.T) {
 			return tm.terminal
 		}
 
-		config.Args = append(config.Args, appID, component)
+		config.Args = append(config.Args, appID, componentName)
+		config.Doit.Set(config.NS, doctl.ArgAppDeployment, deploymentID)
+
+		err := RunAppsConsole(config)
+		require.NoError(t, err)
+	})
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		opts := &godo.AppGetExecOptions{
+			DeploymentID: deploymentID,
+			InstanceName: instanceName,
+		}
+		tm.apps.EXPECT().GetExecWithOpts(appID, componentName, opts).Times(1).Return(&godo.AppExec{URL: "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33"}, nil)
+		tm.listen.EXPECT().Listen(gomock.Any()).Times(1).Return(nil)
+		tm.terminal.EXPECT().ReadRawStdin(gomock.Any(), gomock.Any()).Times(1).Return(func() {}, nil)
+		tm.terminal.EXPECT().MonitorResizeEvents(gomock.Any(), gomock.Any()).Times(1).Return(nil)
+
+		tc := config.Doit.(*doctl.TestConfig)
+		tc.ListenFn = func(url *url.URL, token string, schemaFunc listen.SchemaFunc, out io.Writer, in <-chan []byte) listen.ListenerService {
+			assert.Equal(t, "aa-bb-11-cc-33", token)
+			assert.Equal(t, "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33", url.String())
+			return tm.listen
+		}
+		tc.TerminalFn = func() terminal.Terminal {
+			return tm.terminal
+		}
+
+		config.Args = append(config.Args, appID, componentName, instanceName)
 		config.Doit.Set(config.NS, doctl.ArgAppDeployment, deploymentID)
 
 		err := RunAppsConsole(config)
@@ -1039,3 +1073,136 @@ func TestRunAppsUpgradeBuildpack(t *testing.T) {
 		require.NoError(t, err)
 	})
 }
+
+func TestRunAppsGetInstances(t *testing.T) {
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		appID := uuid.New().String()
+
+		opts := &godo.GetAppInstancesOpts{}
+
+		tm.apps.EXPECT().GetAppInstances(appID, opts).Times(1).Return([]*godo.AppInstance{{
+			InstanceName:  "service-instance-1d34fg678-45f6",
+			ComponentType: "service",
+			ComponentName: "service-instance",
+		}}, nil)
+
+		config.Args = append(config.Args, appID)
+
+		err := RunGetAppInstances(config)
+		require.NoError(t, err)
+	})
+}
+
+func TestRunAppsListJobInvocations(t *testing.T) {
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		appID := uuid.New().String()
+		jobInvocations := []*godo.JobInvocation{{
+			ID:           uuid.New().String(),
+			JobName:      "job-name",
+			DeploymentID: uuid.New().String(),
+			Phase:        godo.JOBINVOCATIONPHASE_Succeeded,
+			Trigger: &godo.JobInvocationTrigger{
+				Type: godo.JOBINVOCATIONTRIGGERTYPE_Scheduled,
+				Scheduled: &godo.TriggerMetadataScheduled{
+					Schedule: &godo.AppJobSpecSchedule{
+						Cron:     "0 0 * * *",
+						TimeZone: "America/New_York",
+					},
+				},
+			},
+			CreatedAt:   time.Now(),
+			StartedAt:   time.Now(),
+			CompletedAt: time.Now(),
+		}}
+
+		opts := &godo.ListJobInvocationsOptions{
+			DeploymentID: jobInvocations[0].DeploymentID,
+			JobNames:     []string{jobInvocations[0].JobName},
+		}
+
+		tm.apps.EXPECT().ListJobInvocations(appID, opts).Times(1).Return(jobInvocations, nil)
+
+		config.Args = append(config.Args, appID)
+		config.Doit.Set(config.NS, doctl.ArgAppDeployment, jobInvocations[0].DeploymentID)
+		config.Doit.Set(config.NS, doctl.ArgAppJobName, jobInvocations[0].JobName)
+
+		err := RunAppsListJobInvocations(config)
+		require.NoError(t, err)
+	})
+}
+
+func TestRunAppsGetJobInvocation(t *testing.T) {
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		appID := uuid.New().String()
+		jobInvocation := &godo.JobInvocation{
+			ID:           uuid.New().String(),
+			JobName:      "job-name",
+			DeploymentID: uuid.New().String(),
+			Phase:        godo.JOBINVOCATIONPHASE_Succeeded,
+			Trigger: &godo.JobInvocationTrigger{
+				Type: godo.JOBINVOCATIONTRIGGERTYPE_Scheduled,
+				Scheduled: &godo.TriggerMetadataScheduled{
+					Schedule: &godo.AppJobSpecSchedule{
+						Cron:     "0 0 * * *",
+						TimeZone: "America/New_York",
+					},
+				},
+			},
+			CreatedAt:   time.Now(),
+			StartedAt:   time.Now(),
+			CompletedAt: time.Now(),
+		}
+
+		opts := &godo.GetJobInvocationOptions{
+			JobName: jobInvocation.JobName,
+		}
+
+		tm.apps.EXPECT().GetJobInvocation(appID, jobInvocation.ID, opts).Times(1).Return(jobInvocation, nil)
+
+		config.Args = append(config.Args, appID, jobInvocation.ID)
+		config.Doit.Set(config.NS, doctl.ArgAppJobName, jobInvocation.JobName)
+
+		err := RunAppsGetJobInvocation(config)
+		require.NoError(t, err)
+	})
+}
+
+func TestRunAppsGetJobInvocationLogs(t *testing.T) {
+	appID := uuid.New().String()
+	jobInvocationID := uuid.New().String()
+	jobName := "good-job"
+
+	testApp := &godo.App{
+		ID:   appID,
+		Spec: &testAppSpec,
+		ActiveDeployment: &godo.Deployment{
+			ID:   uuid.New().String(),
+			Spec: &testAppSpec,
+		},
+	}
+
+	opts := &godo.GetJobInvocationLogsOptions{
+		JobName: jobName,
+		Follow:  true,
+	}
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.apps.EXPECT().Find(appID).Times(1).Return(testApp, nil)
+		tm.apps.EXPECT().GetJobInvocationLogs(appID, jobInvocationID, opts).Times(1).Return(&godo.AppLogs{LiveURL: "https://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33"}, nil)
+		tm.listen.EXPECT().Listen(gomock.Any()).Times(1).Return(nil)
+
+		tc := config.Doit.(*doctl.TestConfig)
+		tc.ListenFn = func(url *url.URL, token string, schemaFunc listen.SchemaFunc, out io.Writer, in <-chan []byte) listen.ListenerService {
+			assert.Equal(t, "aa-bb-11-cc-33", token)
+			assert.Equal(t, "wss://proxy-apps-prod-ams3-001.ondigitalocean.app/?token=aa-bb-11-cc-33", url.String())
+			return tm.listen
+		}
+
+		config.Args = append(config.Args, appID, jobName)
+		config.Doit.Set(config.NS, doctl.ArgAppJobInvocation, jobInvocationID)
+		config.Doit.Set(config.NS, doctl.ArgAppLogFollow, true)
+
+		err := RunAppsGetLogs(config)
+		require.NoError(t, err)
+	})
+}
