@@ -45,6 +45,15 @@ var (
 				ScaleDownUtilizationThreshold: &scaleDownUtilizationThreshold,
 				ScaleDownUnneededTime:         &scaleDownUnneededTime,
 			},
+			RoutingAgent: &godo.KubernetesRoutingAgent{
+				Enabled: boolPtr(true),
+			},
+			AmdGpuDevicePlugin: &godo.KubernetesAmdGpuDevicePlugin{
+				Enabled: boolPtr(true),
+			},
+			AmdGpuDeviceMetricsExporterPlugin: &godo.KubernetesAmdGpuDeviceMetricsExporterPlugin{
+				Enabled: boolPtr(true),
+			},
 		},
 	}
 
@@ -523,6 +532,15 @@ func TestKubernetesCreate(t *testing.T) {
 				ScaleDownUtilizationThreshold: &scaleDownUtilizationThreshold,
 				ScaleDownUnneededTime:         &scaleDownUnneededTime,
 			},
+			RoutingAgent: &godo.KubernetesRoutingAgent{
+				Enabled: boolPtr(true),
+			},
+			AmdGpuDevicePlugin: &godo.KubernetesAmdGpuDevicePlugin{
+				Enabled: boolPtr(true),
+			},
+			AmdGpuDeviceMetricsExporterPlugin: &godo.KubernetesAmdGpuDeviceMetricsExporterPlugin{
+				Enabled: boolPtr(true),
+			},
 		}
 		tm.kubernetes.EXPECT().Create(&r).Return(&testCluster, nil)
 
@@ -549,6 +567,10 @@ func TestKubernetesCreate(t *testing.T) {
 		config.Doit.Set(config.NS, doctl.ArgClusterAutoscalerScaleDownUtilizationThreshold, testCluster.ClusterAutoscalerConfiguration.ScaleDownUtilizationThreshold)
 		config.Doit.Set(config.NS, doctl.ArgClusterAutoscalerScaleDownUnneededTime, testCluster.ClusterAutoscalerConfiguration.ScaleDownUnneededTime)
 
+		config.Doit.Set(config.NS, doctl.ArgEnableRoutingAgent, testCluster.RoutingAgent.Enabled)
+		config.Doit.Set(config.NS, doctl.ArgEnableAmdGpuDevicePlugin, testCluster.AmdGpuDevicePlugin.Enabled)
+		config.Doit.Set(config.NS, doctl.ArgEnableAmdGpuDeviceMetricsExporterPlugin, testCluster.AmdGpuDeviceMetricsExporterPlugin.Enabled)
+
 		// Test with no vpc-uuid specified
 		err := testK8sCmdService().RunKubernetesClusterCreate("c-8", 3)(config)
 		assert.NoError(t, err)
@@ -606,6 +628,15 @@ func TestKubernetesUpdate(t *testing.T) {
 				ScaleDownUtilizationThreshold: &scaleDownUtilizationThreshold,
 				ScaleDownUnneededTime:         &scaleDownUnneededTime,
 			},
+			RoutingAgent: &godo.KubernetesRoutingAgent{
+				Enabled: boolPtr(true),
+			},
+			AmdGpuDevicePlugin: &godo.KubernetesAmdGpuDevicePlugin{
+				Enabled: boolPtr(true),
+			},
+			AmdGpuDeviceMetricsExporterPlugin: &godo.KubernetesAmdGpuDeviceMetricsExporterPlugin{
+				Enabled: boolPtr(true),
+			},
 		}
 		tm.kubernetes.EXPECT().Update(testCluster.ID, &r).Return(&testCluster, nil)
 
@@ -619,6 +650,9 @@ func TestKubernetesUpdate(t *testing.T) {
 		config.Doit.Set(config.NS, doctl.ArgControlPlaneFirewallAllowedAddresses, testCluster.ControlPlaneFirewall.AllowedAddresses)
 		config.Doit.Set(config.NS, doctl.ArgClusterAutoscalerScaleDownUtilizationThreshold, testCluster.ClusterAutoscalerConfiguration.ScaleDownUtilizationThreshold)
 		config.Doit.Set(config.NS, doctl.ArgClusterAutoscalerScaleDownUnneededTime, testCluster.ClusterAutoscalerConfiguration.ScaleDownUnneededTime)
+		config.Doit.Set(config.NS, doctl.ArgEnableRoutingAgent, testCluster.RoutingAgent.Enabled)
+		config.Doit.Set(config.NS, doctl.ArgEnableAmdGpuDevicePlugin, testCluster.AmdGpuDevicePlugin.Enabled)
+		config.Doit.Set(config.NS, doctl.ArgEnableAmdGpuDeviceMetricsExporterPlugin, testCluster.AmdGpuDeviceMetricsExporterPlugin.Enabled)
 
 		err := testK8sCmdService().RunKubernetesClusterUpdate(config)
 		assert.NoError(t, err)
@@ -645,6 +679,9 @@ func TestKubernetesUpdate(t *testing.T) {
 				ScaleDownUtilizationThreshold: &scaleDownUtilizationThreshold,
 				ScaleDownUnneededTime:         &scaleDownUnneededTime,
 			},
+			RoutingAgent: &godo.KubernetesRoutingAgent{
+				Enabled: boolPtr(true),
+			},
 		}
 		tm.kubernetes.EXPECT().List().Return(testClusterList, nil)
 		tm.kubernetes.EXPECT().Update(testCluster.ID, &r).Return(&testCluster, nil)
@@ -658,6 +695,7 @@ func TestKubernetesUpdate(t *testing.T) {
 		config.Doit.Set(config.NS, doctl.ArgControlPlaneFirewallAllowedAddresses, testCluster.ControlPlaneFirewall.AllowedAddresses)
 		config.Doit.Set(config.NS, doctl.ArgClusterAutoscalerScaleDownUtilizationThreshold, testCluster.ClusterAutoscalerConfiguration.ScaleDownUtilizationThreshold)
 		config.Doit.Set(config.NS, doctl.ArgClusterAutoscalerScaleDownUnneededTime, testCluster.ClusterAutoscalerConfiguration.ScaleDownUnneededTime)
+		config.Doit.Set(config.NS, doctl.ArgEnableRoutingAgent, testCluster.RoutingAgent.Enabled)
 
 		err := testK8sCmdService().RunKubernetesClusterUpdate(config)
 		assert.NoError(t, err)
